import type { NextApiRequest, NextApiResponse } from 'next';
import nodemailer from 'nodemailer';

// Nodemailer docs: // https://nodemailer.com/about/
export default async function handler(
  req: NextApiRequest,
  res: NextApiResponse
) {
  if (req.method !== "POST") {
    return res.status(405).json({ error: "Method Not Allowed" });
  }
  // https://nodemailer.com/smtp/
  const transporter = nodemailer.createTransport({
    host: "smtp.gameunity.tgos@gmail.com",
    port: 587,
    auth: {
      user: process.env.NODEMAIL_MAIL,
      pass: process.env.NODEMAIL_PW,
    },
  });

  const { subject, email, html } = req.body;

  if (!subject || !email || !html) {
    return res
      .status(400)
      .json({ message: 'Please fill out the necessary fields' });
  }

  // https://nodemailer.com/message/#common-fields
  const mailData = {
    from: process.env.NODEMAIL_MAIL,
    to: email,
    subject: `${subject}`,
    text: `${subject} | Sent from: ${process.env.NODEMAIL_MAIL}`,
    html: `${html}`,
  };

  try {
    const info = await transporter.sendMail(mailData);
    res.status(200).json({ message: 'Message sent!', info });
  } catch (err) {
    res.status(500).json({ error: err || 'Something went wrong Message could not be send' });
  }

  return;
}